package com.inet.application.googleanalytics;

import com.inet.application.googleanalytics.structure.GoogleAnalyticsStructureProvider;
import com.inet.config.structure.provider.ConfigStructureProvider;
import com.inet.file.CombinedFileDescription;
import com.inet.file.FileCombiner.CombinedFile;
import com.inet.plugin.PluginInfo;
import com.inet.plugin.ServerPlugin;
import com.inet.plugin.ServerPluginManager;
import com.inet.remote.gui.RemoteGuiServerPlugin;

/**
 * Plugin to add a GA tracking script to the remite interface.
 * Has to be configured with the GA-TrackingID
 */
@PluginInfo(
id = "application.gooogleanalytics", //
flags = "core",
packages = "", //
icon = "com/inet/application/googleanalytics/analytics_48.png", //
group = "samples", //
version = ServerPlugin.CORE_VERSION //
)
public class GoogleAnalyticsServerPlugin implements ServerPlugin {

    /**
     * {@inheritDoc}
     */
    @Override
    public void registerExtension( ServerPluginManager spm ) {
        // register optional additional java script
        CombinedFile combinedFile = new CombinedFile( "application/x-javascript; charset=utf-8" );

        // add at least one javascript resource
        combinedFile.add( getClass(), "googleanalytics.js" );
        combinedFile.addRuntimeData( new GoogleAnalyticsRuntimeData() );
        spm.register( CombinedFileDescription.class, new CombinedFileDescription( RemoteGuiServerPlugin.APP_KEY, 20000, "remotegui.lib.js", combinedFile ) );

        spm.register( ConfigStructureProvider.class, new GoogleAnalyticsStructureProvider() );
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void init( ServerPluginManager spm ) {
        // nothing
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void reset() {
        // nothing
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void restart() {
        // nothing
    }

}
